@@ -663,6 +663,59 @@ predict( estResultLaT, newdata = B86new, observedShares = TRUE )
 predict( estResultLaT, newdata = B86new )
 
 
+###############  aidsUtility  #################
+coefTl <- coef( estResultTl )
+aidsUtility( pNames, "xFood", coef = coefTl, data = Blanciforti86[ set, ] )
+coefTl$beta0 <- 2
+aidsUtility( pNames, "xFood", coef = coefTl, data = Blanciforti86[ set, ] )
+
+aidsUtility( pNames, "xFood", coef = coef( estResultAIDS ),
+   data = Blanciforti86[ setWo1, ] )
+
+aidsUtility( pNames, "xFood", coef = coef( estResultAIDShom ),
+   data = Blanciforti86[ setWo1, ] )
+
+aidsUtility( pNames, "xFood", coef = coef( estResultAIDSunr ),
+   data = Blanciforti86[ setWo1, ] )
+
+aidsUtility( pNames, "xFood", coef = coef( estResultAIDSNa ),
+   data = Blanciforti86[ setWo1, ] )
+
+
+###############  aidsUtilityDeriv  #################
+coefTl <- coef( estResultTl )
+aidsUtilityDeriv( pNames, "xFood", coef = coefTl,
+   data = Blanciforti86[ set, ] )
+aidsUtilityDeriv( pNames, "xFood", coef = coefTl,
+   data = Blanciforti86[ set, ], rel = TRUE )
+
+coefTl$beta0 <- 2
+aidsUtilityDeriv( pNames, "xFood", coef = coefTl,
+   data = Blanciforti86[ set, ] )
+aidsUtilityDeriv( pNames, "xFood", coef = coefTl,
+   data = Blanciforti86[ set, ], rel = TRUE )
+
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDS ),
+   data = Blanciforti86[ setWo1, ] )
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDS ),
+   data = Blanciforti86[ setWo1, ], rel = TRUE )
+
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDShom ),
+   data = Blanciforti86[ setWo1, ] )
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDShom ),
+   data = Blanciforti86[ setWo1, ], rel = TRUE )
+
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDSunr ),
+   data = Blanciforti86[ setWo1, ] )
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDSunr ),
+   data = Blanciforti86[ setWo1, ], rel = TRUE )
+
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDSNa ),
+   data = Blanciforti86[ setWo1, ] )
+aidsUtilityDeriv( pNames, "xFood", coef = coef( estResultAIDSNa ),
+   data = Blanciforti86[ setWo1, ], rel = TRUE )
+
+
 ####### monotonicity ###################
 # AIDS
 monoAids <- aidsMono( pNames, "xFood", coef = coef( estResultAIDS ),
